@@ -27,16 +27,16 @@
 #' arrange(right, year)
 order_by <- function(order_by, call) {
   quo <- enquo(call)
-  if (!quo_is_lang(quo)) {
+  if (!quo_is_call(quo)) {
     type <- friendly_type(type_of(get_expr(quo)))
     bad_args("call", "must be a function call, not { type }")
   }
 
   fn <- set_expr(quo, node_car(get_expr(quo)))
   args <- node_cdr(get_expr(quo))
-  args <- map(args, new_quosure, f_env(quo))
+  args <- map(args, new_quosure, quo_get_env(quo))
 
-  quo <- quo(with_order(!! order_by, !! fn, !!! args))
+  quo <- quo(with_order(!!order_by, !!fn, !!!args))
   eval_tidy(quo)
 }
 
