@@ -6,7 +6,9 @@
 #' @keywords internal
 #' @param data a data frame
 tbl_df <- function(data) {
-  as_data_frame(data)
+  # Works in tibble < 1.5.0 too, because .name_repair will be
+  # swallowed by the ellipsis
+  as_tibble(data, .name_repair = "check_unique")
 }
 
 #' @export
@@ -27,17 +29,6 @@ auto_copy.tbl_df <- function(x, y, copy = FALSE, ...) {
   as.data.frame(y)
 }
 
-# Grouping methods ------------------------------------------------------------
-
-# These are all inherited from data.frame - see tbl-data-frame.R
-
-# Standard data frame methods --------------------------------------------------
-
-#' @export
-as.data.frame.tbl_df <- function(x, row.names = NULL, optional = FALSE, ...) {
-  as_regular_df(x)
-}
-
 # Verbs ------------------------------------------------------------------------
 
 #' @export
